@@ -1,4 +1,4 @@
-// Copyright (C) 2004-2023 Artifex Software, Inc.
+// Copyright (C) 2004-2025 Artifex Software, Inc.
 //
 // This file is part of MuPDF.
 //
@@ -22,6 +22,7 @@
 
 /* Alphabetically sorted list of all PDF names to be available as constants */
 PDF_MAKE_NAME("1.2", 1_2)
+PDF_MAKE_NAME("1.5", 1_5)
 PDF_MAKE_NAME("3D", 3D)
 PDF_MAKE_NAME("A", A)
 PDF_MAKE_NAME("A85", A85)
@@ -29,11 +30,14 @@ PDF_MAKE_NAME("AA", AA)
 PDF_MAKE_NAME("AC", AC)
 PDF_MAKE_NAME("AESV2", AESV2)
 PDF_MAKE_NAME("AESV3", AESV3)
+PDF_MAKE_NAME("AF", AF)
+PDF_MAKE_NAME("AFRelationship", AFRelationship)
 PDF_MAKE_NAME("AHx", AHx)
 PDF_MAKE_NAME("AP", AP)
 PDF_MAKE_NAME("AS", AS)
 PDF_MAKE_NAME("ASCII85Decode", ASCII85Decode)
 PDF_MAKE_NAME("ASCIIHexDecode", ASCIIHexDecode)
+PDF_MAKE_NAME("AbsoluteColorimetric", AbsoluteColorimetric)
 PDF_MAKE_NAME("AcroForm", AcroForm)
 PDF_MAKE_NAME("Action", Action)
 PDF_MAKE_NAME("ActualText", ActualText)
@@ -44,6 +48,7 @@ PDF_MAKE_NAME("AllOn", AllOn)
 PDF_MAKE_NAME("Alpha", Alpha)
 PDF_MAKE_NAME("Alt", Alt)
 PDF_MAKE_NAME("Alternate", Alternate)
+PDF_MAKE_NAME("Alternative", Alternative)
 PDF_MAKE_NAME("Annot", Annot)
 PDF_MAKE_NAME("Annots", Annots)
 PDF_MAKE_NAME("AnyOff", AnyOff)
@@ -82,6 +87,8 @@ PDF_MAKE_NAME("BlockQuote", BlockQuote)
 PDF_MAKE_NAME("Border", Border)
 PDF_MAKE_NAME("Bounds", Bounds)
 PDF_MAKE_NAME("Box", Box)
+PDF_MAKE_NAME("Br", Br)
+PDF_MAKE_NAME("BrotliDecode", BrotliDecode)
 PDF_MAKE_NAME("Bt", Bt)
 PDF_MAKE_NAME("Btn", Btn)
 PDF_MAKE_NAME("Butt", Butt)
@@ -100,11 +107,15 @@ PDF_MAKE_NAME("CIDFontType0C", CIDFontType0C)
 PDF_MAKE_NAME("CIDFontType2", CIDFontType2)
 PDF_MAKE_NAME("CIDSystemInfo", CIDSystemInfo)
 PDF_MAKE_NAME("CIDToGIDMap", CIDToGIDMap)
+PDF_MAKE_NAME("CL", CL)
 PDF_MAKE_NAME("CMYK", CMYK)
+PDF_MAKE_NAME("CO", CO)
+PDF_MAKE_NAME("CP", CP)
 PDF_MAKE_NAME("CS", CS)
 PDF_MAKE_NAME("CalCMYK", CalCMYK)
 PDF_MAKE_NAME("CalGray", CalGray)
 PDF_MAKE_NAME("CalRGB", CalRGB)
+PDF_MAKE_NAME("Cap", Cap)
 PDF_MAKE_NAME("CapHeight", CapHeight)
 PDF_MAKE_NAME("Caption", Caption)
 PDF_MAKE_NAME("Caret", Caret)
@@ -194,6 +205,7 @@ PDF_MAKE_NAME("EncodedByteAlign", EncodedByteAlign)
 PDF_MAKE_NAME("Encoding", Encoding)
 PDF_MAKE_NAME("Encrypt", Encrypt)
 PDF_MAKE_NAME("EncryptMetadata", EncryptMetadata)
+PDF_MAKE_NAME("EncryptedPayload", EncryptedPayload)
 PDF_MAKE_NAME("EndOfBlock", EndOfBlock)
 PDF_MAKE_NAME("EndOfLine", EndOfLine)
 PDF_MAKE_NAME("Exclude", Exclude)
@@ -243,10 +255,13 @@ PDF_MAKE_NAME("FontName", FontName)
 PDF_MAKE_NAME("ForComment", ForComment)
 PDF_MAKE_NAME("ForPublicRelease", ForPublicRelease)
 PDF_MAKE_NAME("Form", Form)
+PDF_MAKE_NAME("FormData", FormData)
 PDF_MAKE_NAME("FormEx", FormEx)
 PDF_MAKE_NAME("FormType", FormType)
 PDF_MAKE_NAME("Formula", Formula)
 PDF_MAKE_NAME("FreeText", FreeText)
+PDF_MAKE_NAME("FreeTextCallout", FreeTextCallout)
+PDF_MAKE_NAME("FreeTextTypeWriter", FreeTextTypeWriter)
 PDF_MAKE_NAME("Function", Function)
 PDF_MAKE_NAME("FunctionType", FunctionType)
 PDF_MAKE_NAME("Functions", Functions)
@@ -274,6 +289,7 @@ PDF_MAKE_NAME("ICCBased", ICCBased)
 PDF_MAKE_NAME("ID", ID)
 PDF_MAKE_NAME("IM", IM)
 PDF_MAKE_NAME("IRT", IRT)
+PDF_MAKE_NAME("IT", IT)
 PDF_MAKE_NAME("Identity", Identity)
 PDF_MAKE_NAME("Identity-H", Identity_H)
 PDF_MAKE_NAME("Identity-V", Identity_V)
@@ -306,6 +322,9 @@ PDF_MAKE_NAME("LC", LC)
 PDF_MAKE_NAME("LE", LE)
 PDF_MAKE_NAME("LI", LI)
 PDF_MAKE_NAME("LJ", LJ)
+PDF_MAKE_NAME("LL", LL)
+PDF_MAKE_NAME("LLE", LLE)
+PDF_MAKE_NAME("LLO", LLO)
 PDF_MAKE_NAME("LW", LW)
 PDF_MAKE_NAME("LZ", LZ)
 PDF_MAKE_NAME("LZW", LZW)
@@ -325,6 +344,8 @@ PDF_MAKE_NAME("Length2", Length2)
 PDF_MAKE_NAME("Length3", Length3)
 PDF_MAKE_NAME("Limits", Limits)
 PDF_MAKE_NAME("Line", Line)
+PDF_MAKE_NAME("LineArrow", LineArrow)
+PDF_MAKE_NAME("LineDimension", LineDimension)
 PDF_MAKE_NAME("Linearized", Linearized)
 PDF_MAKE_NAME("Link", Link)
 PDF_MAKE_NAME("List", List)
@@ -405,9 +426,14 @@ PDF_MAKE_NAME("ParentTree", ParentTree)
 PDF_MAKE_NAME("Part", Part)
 PDF_MAKE_NAME("Pattern", Pattern)
 PDF_MAKE_NAME("PatternType", PatternType)
+PDF_MAKE_NAME("Perceptual", Perceptual)
 PDF_MAKE_NAME("Perms", Perms)
+PDF_MAKE_NAME("PieceInfo", PieceInfo)
 PDF_MAKE_NAME("PolyLine", PolyLine)
+PDF_MAKE_NAME("PolyLineDimension", PolyLineDimension)
 PDF_MAKE_NAME("Polygon", Polygon)
+PDF_MAKE_NAME("PolygonCloud", PolygonCloud)
+PDF_MAKE_NAME("PolygonDimension", PolygonDimension)
 PDF_MAKE_NAME("Popup", Popup)
 PDF_MAKE_NAME("PreRelease", PreRelease)
 PDF_MAKE_NAME("Predictor", Predictor)
@@ -438,9 +464,11 @@ PDF_MAKE_NAME("REx", REx)
 PDF_MAKE_NAME("RGB", RGB)
 PDF_MAKE_NAME("RI", RI)
 PDF_MAKE_NAME("RL", RL)
+PDF_MAKE_NAME("RO", RO)
 PDF_MAKE_NAME("ROpenArrow", ROpenArrow)
 PDF_MAKE_NAME("RP", RP)
 PDF_MAKE_NAME("RT", RT)
+PDF_MAKE_NAME("RV", RV)
 PDF_MAKE_NAME("Range", Range)
 PDF_MAKE_NAME("Reason", Reason)
 PDF_MAKE_NAME("Rect", Rect)
@@ -448,6 +476,7 @@ PDF_MAKE_NAME("Redact", Redact)
 PDF_MAKE_NAME("Ref", Ref)
 PDF_MAKE_NAME("Reference", Reference)
 PDF_MAKE_NAME("Registry", Registry)
+PDF_MAKE_NAME("RelativeColorimetric", RelativeColorimetric)
 PDF_MAKE_NAME("ResetForm", ResetForm)
 PDF_MAKE_NAME("Resources", Resources)
 PDF_MAKE_NAME("RoleMap", RoleMap)
@@ -459,6 +488,7 @@ PDF_MAKE_NAME("RunLengthDecode", RunLengthDecode)
 PDF_MAKE_NAME("S", S)
 PDF_MAKE_NAME("SMask", SMask)
 PDF_MAKE_NAME("SMaskInData", SMaskInData)
+PDF_MAKE_NAME("Saturation", Saturation)
 PDF_MAKE_NAME("Schema", Schema)
 PDF_MAKE_NAME("Screen", Screen)
 PDF_MAKE_NAME("Sect", Sect)
@@ -474,12 +504,15 @@ PDF_MAKE_NAME("Size", Size)
 PDF_MAKE_NAME("Slash", Slash)
 PDF_MAKE_NAME("Sold", Sold)
 PDF_MAKE_NAME("Sound", Sound)
+PDF_MAKE_NAME("Source", Source)
 PDF_MAKE_NAME("Span", Span)
 PDF_MAKE_NAME("Split", Split)
 PDF_MAKE_NAME("Square", Square)
 PDF_MAKE_NAME("Squiggly", Squiggly)
 PDF_MAKE_NAME("St", St)
 PDF_MAKE_NAME("Stamp", Stamp)
+PDF_MAKE_NAME("StampImage", StampImage)
+PDF_MAKE_NAME("StampSnapshot", StampSnapshot)
 PDF_MAKE_NAME("Standard", Standard)
 PDF_MAKE_NAME("StdCF", StdCF)
 PDF_MAKE_NAME("StemV", StemV)
@@ -511,10 +544,12 @@ PDF_MAKE_NAME("TR2", TR2)
 PDF_MAKE_NAME("TU", TU)
 PDF_MAKE_NAME("Table", Table)
 PDF_MAKE_NAME("Text", Text)
+PDF_MAKE_NAME("Thumb", Thumb)
 PDF_MAKE_NAME("TilingType", TilingType)
 PDF_MAKE_NAME("Times", Times)
 PDF_MAKE_NAME("Title", Title)
 PDF_MAKE_NAME("ToUnicode", ToUnicode)
+PDF_MAKE_NAME("Top", Top)
 PDF_MAKE_NAME("TopSecret", TopSecret)
 PDF_MAKE_NAME("Trans", Trans)
 PDF_MAKE_NAME("TransformMethod", TransformMethod)
@@ -539,6 +574,7 @@ PDF_MAKE_NAME("Unchanged", Unchanged)
 PDF_MAKE_NAME("Uncover", Uncover)
 PDF_MAKE_NAME("Underline", Underline)
 PDF_MAKE_NAME("Unix", Unix)
+PDF_MAKE_NAME("Unspecified", Unspecified)
 PDF_MAKE_NAME("Usage", Usage)
 PDF_MAKE_NAME("UseBlackPtComp", UseBlackPtComp)
 PDF_MAKE_NAME("UseCMap", UseCMap)
